@@ -2,31 +2,13 @@ import sqlite3
 import pandas as pd
 import pathlib
 from deez_stats.telo.telo import Elo
+from deez_stats.matchup_history import MatchupHistory
 
 INIT_ELO = 700
 HERE = (pathlib.Path(__file__).parent)
 DATABASE_FILE = (HERE / 'files/database/history.db')
 
 
-# class DatabaseNav:
-#     def __init__(self):
-#         self.connection = None
-#         self.cursor = None
-
-#     def start_connection(self):
-#         self.connection = sqlite3.connect(DATABASE_FILE)
-#         self.cursor = self.connection.cursor()
-
-#     def close_connection(self, commit=False):
-#         self.cursor.close()
-#         if commit is True:
-#             self.connection.commit()
-#         self.connection.close()
-
-#     def execute_sql(self, sql_query):
-#         self.start_connection()
-
-
 def execute_sqlite(sql_query):
     connection = sqlite3.connect(DATABASE_FILE)
     cursor = connection.cursor()
@@ -61,21 +43,38 @@ def execute_row_factory(sql_query):
     return result
 
 
-def matchup_history(manager_name, opponent_name, display=True):
-    class MatchupHistory:
-        def __init__(self):
-            self.manager_name = manager_name
-            self.opponent_name = opponent_name
-            self.manager_avg_score = None
-            self.opponent_avg_score = None
-            self.manager_wins = 0
-            self.opponent_wins = 0
-            self.matchup_history = None
+def get_matchup_history(manager_name, opponent_name):
+    """Gets all of the historical matchups and run some basic stats
 
+    """
+    mh = MatchupHistory(manager_name, opponent_name)
+
+    all_historical_matchups = find_all_historical_matchups(manager_name, opponent_name)
+
+    columns = ['Season', 'Manager Score', 'Opponent Score', 'Result']
+    mh.matchup_history_df = pd.DataFrame(all_historical_matchups, columns=columns)
+
+    mh.manager_avg_score = mh.matchup_history_df['Manager Score'].mean()
+    mh.opponent_avg_score = mh.matchup_history_df['Opponent Score'].mean()
+
+    try:
+        mh.manager_wins = mh.matchup_history_df.Result.value_counts().W
+    except AttributeError:
+        mh.manager_wins = 0
+
+    try:
+        mh.opponent_wins = mh.matchup_history_df.Result.value_counts().L
+    except AttributeError:
+        mh.opponent_wins = 0
+    return mh
+
+
+def find_all_historical_matchups(manager_name, opponent_name):
+    """Finds all of the historical matchups in the database
+
+    """
     query_string = '''
         SELECT  season,
-                manager_name,
-                opponent_name,
                 manager_score,
                 opponent_score,
                 result
@@ -83,106 +82,83 @@ def matchup_history(manager_name, opponent_name, display=True):
         WHERE   manager_name = "{}" AND opponent_name = "{}"
     '''.format(manager_name, opponent_name)
     result = execute_sqlite(query_string)
-
-    mh = MatchupHistory()
-
-    df = pd.DataFrame(result, columns=['season', 'Manager', 'Opponent', 'Manager Score', 'Opponent Score', 'Result'])
-    mh.manager_avg_score = df['Manager Score'].mean()
-    mh.opponent_avg_score = df['Opponent Score'].mean()
-
-    try:
-        mh.manager_wins = df.Result.value_counts().W
-    except AttributeError:
-        mh.manager_wins = 0
-
-    try:
-        mh.opponent_wins = df.Result.value_counts().L
-    except AttributeError:
-        mh.opponent_wins = 0
-    return mh
-
-
-def get_manager_score_history(manager_name):
-    query_string = '''
-        SELECT  manager_score
-        FROM    schedule
-        WHERE   manager_name = "{}"
-        ORDER BY manager_score DESC;
-    '''.format(manager_name)
-    result = execute_row_factory(query_string)
     return result
 
 
-def update_weekly_results(leagueinfo, season, week, update=False, display=True):
-    if leagueinfo.end_week - week == 1:  # check if semifinals
-        d = find_weekly_winners(season=season, week=week - 1)
-        quarterfinal_winners = [i[0] for i in d]
-        semifinals = []
-        matchups = leagueinfo.weekly_matchups
-        for idx, name in enumerate(matchups):
-            if name[0] not in quarterfinal_winners:
-                if idx % 2 == 0:
-                    if matchups[idx + 1][0] in quarterfinal_winners:
-                        semifinals.append(name)
-                else:
-                    if matchups[idx - 1][0] in quarterfinal_winners:
-                        semifinals.append(name)
-            if name[0] in quarterfinal_winners:
-                semifinals.append(name)
-        leagueinfo.weekly_matchups = semifinals
-    elif leagueinfo.end_week - week == 0:  # check if finals
-        d = find_seminfinal_managers(season=season, week=week - 1)
-        semifinal_names = [i[0] for i in d]
-        finals = []
-        matchups = leagueinfo.weekly_matchups
-        for idx, name in enumerate(matchups):
-            if name[0] in semifinal_names:
-                finals.append(name)
-        leagueinfo.weekly_matchups = finals
+def update_weekly_results(li, update=False):
+    # if leagueinfo.end_week - week == 1:  # check if semifinals
+    #     d = find_weekly_winners(season=season, week=week - 1)
+    #     quarterfinal_winners = [i[0] for i in d]
+    #     semifinals = []
+    #     matchups = leagueinfo.weekly_matchups
+    #     for idx, name in enumerate(matchups):
+    #         if name[0] not in quarterfinal_winners:
+    #             if idx % 2 == 0:
+    #                 if matchups[idx + 1][0] in quarterfinal_winners:
+    #                     semifinals.append(name)
+    #             else:
+    #                 if matchups[idx - 1][0] in quarterfinal_winners:
+    #                     semifinals.append(name)
+    #         if name[0] in quarterfinal_winners:
+    #             semifinals.append(name)
+    #     leagueinfo.weekly_matchups = semifinals
+    # elif leagueinfo.end_week - week == 0:  # check if finals
+    #     d = find_seminfinal_managers(season=season, week=week - 1)
+    #     semifinal_names = [i[0] for i in d]
+    #     finals = []
+    #     matchups = leagueinfo.weekly_matchups
+    #     for idx, name in enumerate(matchups):
+    #         if name[0] in semifinal_names:
+    #             finals.append(name)
+    #     leagueinfo.weekly_matchups = finals
 
-    df = pd.DataFrame(leagueinfo.weekly_matchups, columns=['manager_name', 'manager_score'])
-    df.insert(0, 'season', df.shape[0] * [leagueinfo.season])
-    df.insert(1, 'week', leagueinfo.week)
-    opponents = df.shape[0] * ['']
-    opponent_scores = df.shape[0] * [0]
-    results = []
-    for i in range(df.shape[0] // 2):
-        opponents[2 * i + 1] = df['manager_name'][2 * i]
-        opponents[2 * i] = df['manager_name'][2 * i + 1]
-        opponent_scores[2 * i + 1] = df['manager_score'][2 * i]
-        opponent_scores[2 * i] = df['manager_score'][2 * i + 1]
-        if df['manager_score'][2 * i] > df['manager_score'][2 * i + 1]:
-            results.append('W')
-            results.append('L')
+    for i in range(len(li.weekly_matchups)):
+        row = [li.season]
+        row.append(li.week)
+        row.append(li.weekly_matchups[i].manager_name)
+        row.append(li.weekly_matchups[i].manager_points_total)
+        row.append(li.weekly_matchups[i].opponent_name)
+        row.append(li.weekly_matchups[i].opponent_points_total)
+        if li.weekly_matchups[i].manager_points_total > li.weekly_matchups[i].opponent_points_total:
+            row.append('W')
         else:
-            results.append('L')
-            results.append('W')
+            row.append('L')
+        # m_elo = get_manager_elo(li.season, li.week, li.weekly_matchups[i].manager_name)
+        # o_elo = get_manager_elo(li.season, li.week, li.weekly_matchups[i].opponent_name)
+        # row.append(m_elo)
+        if update is True:
+            update_database_row(row)
 
-    df['opponent_name'] = opponents
-    df['opponent_score'] = opponent_scores
-    df['results'] = results
-    df['elo'] = df.shape[0] * [0]
+        row = [li.season]
+        row.append(li.week)
+        row.append(li.weekly_matchups[i].opponent_name)
+        row.append(li.weekly_matchups[i].opponent_points_total)
+        row.append(li.weekly_matchups[i].manager_name)
+        row.append(li.weekly_matchups[i].manager_points_total)
+        if li.weekly_matchups[i].opponent_points_total > li.weekly_matchups[i].manager_points_total:
+            row.append('W')
+        else:
+            row.append('L')
+        # o_elo = get_manager_elo(li.season, li.week, li.weekly_matchups[i].opponent_name)
+        # row.append(m_elo)
+        if update is True:
+            update_database_row(row)
 
-    if display is True:
-        print(df)
 
-    if update is True:
-        for i in range(df.shape[0]):
-            row = df.iloc[[i]]  # based on index
-            row = row.values.tolist()[0]
-            query_string = '''
-                INSERT INTO     schedule (
-                                season,
-                                week,
-                                manager_name,
-                                manager_score,
-                                opponent_name,
-                                opponent_score,
-                                result,
-                                elo)
-                VALUES          ({}, {}, '{}', {}, '{}', {}, '{}', {})
-            '''.format(*row)
-            execute_commit(query_string)
+def update_database_row(row):
+    query_string = '''
+        INSERT INTO     schedule (
+                        season,
+                        week,
+                        manager_name,
+                        manager_score,
+                        opponent_name,
+                        opponent_score,
+                        result,
+                        elo)
+        VALUES          ({}, {}, '{}', {}, '{}', {}, '{}', NULL)
+    '''.format(*row)
+    execute_commit(query_string)
 
 
 def get_past_matchups(season, week):
@@ -314,3 +290,33 @@ def get_weekly_df(season, week):
     current_week_df = pd.DataFrame(get_past_matchups(season, week))
     current_week_df.columns = get_table_column_names('schedule')
     return current_week_df
+
+
+def _get_previous_week_season(current_week, current_season, prev_year=False):
+    if (current_week - 1) == 0:
+        season = current_season - 1
+        if season > 2020:
+            week = 18
+        else:
+            week = 17
+        prev_year = True
+    else:
+        week = current_week - 1
+        season = current_season
+        prev_year = False
+
+    return [week, season, prev_year]
+
+# def find_previous_week(current_week, current_season):
+
+# miscellaneous functions that may be helpful
+
+# def get_manager_score_history(manager_name):
+#     query_string = '''
+#         SELECT  manager_score
+#         FROM    schedule
+#         WHERE   manager_name = "{}"
+#         ORDER BY manager_score DESC;
+#     '''.format(manager_name)
+#     result = execute_row_factory(query_string)
+#     return result
